@@ -57,6 +57,8 @@ class ModelLoader:
                 conf.combine = self._conf.combine
                 # we want to use the current workspace parameters
                 conf.workspace = self._conf.workspace
+                # when we load the models, we want to use the current log_transform_target_predict_actuals
+                conf.process.log_transform_target_predict_actuals = self._conf.process.log_transform_target_predict_actuals
                 # we load the model, we've made 0 predictions
                 conf.model.nrows_score = 0
                 conf.timetag = self._conf.timetag
